@@ -5,20 +5,25 @@ pub struct Gen {
     pub root: &'static str,
     pub ignore_windows_features: bool,
     pub docs: bool,
+    pub build: bool,
 }
 
 impl Gen {
     pub fn absolute() -> Self {
-        Gen { relative: "", root: "", ignore_windows_features: false, docs: false }
+        Gen { relative: "", root: "", ignore_windows_features: false, docs: false, build: false }
     }
 
     pub fn relative(namespace: &'static str) -> Self {
-        Gen { relative: namespace, root: "", ignore_windows_features: false, docs: false }
+        Gen { relative: namespace, root: "", ignore_windows_features: false, docs: false, build: false }
+    }
+
+    pub fn build(namespace: &'static str, redirect: bool) -> Self {
+        Gen { relative: namespace, root: "", ignore_windows_features: false, docs: false, build: redirect }
     }
 
     pub fn namespace(&self, namespace: &str) -> TokenStream {
         if self.relative.is_empty() {
-            let mut tokens = TokenStream::with_capacity();
+            let mut tokens = TokenStream::new();
 
             for namespace in namespace.split('.') {
                 tokens.push_str(namespace);
@@ -31,7 +36,7 @@ impl Gen {
                 return TokenStream::new();
             }
 
-            if !self.root.is_empty() && self.root != "Windows" && namespace.starts_with("Windows.") {
+            if (self.build || (!self.root.is_empty() && self.root != "Windows")) && namespace.starts_with("Windows.") {
                 let mut tokens: TokenStream = "::windows::".into();
 
                 for namespace in namespace.split('.').skip(1) {
@@ -53,7 +58,7 @@ impl Gen {
                 namespace.next();
             }
 
-            let mut tokens = TokenStream::with_capacity();
+            let mut tokens = TokenStream::new();
 
             for _ in 0..relative.count() {
                 tokens.push_str("super::");
@@ -118,7 +123,7 @@ impl Gen {
                 continue;
             }
 
-            let feature = if feature.starts_with(self.root) && feature[self.root.len()..].starts_with('.') { &feature[self.root.len() + 1..] } else { &feature };
+            let feature = if feature.starts_with(self.root) && feature[self.root.len()..].starts_with('.') { &feature[self.root.len() + 1..] } else { feature };
             tokens.push_str(&format!(", `{}`", feature.replace('.', "_")));
         }
 
@@ -181,7 +186,7 @@ impl Gen {
                 continue;
             }
 
-            let feature = if feature.starts_with(self.root) && feature[self.root.len()..].starts_with('.') { &feature[self.root.len() + 1..] } else { &feature };
+            let feature = if feature.starts_with(self.root) && feature[self.root.len()..].starts_with('.') { &feature[self.root.len() + 1..] } else { feature };
             tokens.push_str(&format!("feature = \"{}\", ", feature.replace('.', "_")));
             count += 1;
         }
@@ -236,32 +241,12 @@ mod tests {
     fn test_features() {
         let mut features = BTreeSet::new();
         features.insert("Windows.Foundation");
-        assert_eq!(Gen { root: "Microsoft", relative: "", ignore_windows_features: false, docs: false }.gen_cfg(&features).as_str(), r#"#[cfg(feature = "Windows_Foundation")]"#);
-        assert_eq!(
-            Gen {
-                root: "Microsoft",
-                relative: "Microsoft.UI.Composition.Diagnostics",
-                ignore_windows_features: false,
-                docs: true
-            }
-            .gen_cfg_doc(&features)
-            .as_str(),
-            r#"#[doc = "*Required features: `UI_Composition_Diagnostics`, `Windows_Foundation`*"]"#
-        );
+        assert_eq!(Gen { root: "Microsoft", relative: "", ignore_windows_features: false, docs: false, build: false }.gen_cfg(&features).as_str(), r#"#[cfg(feature = "Windows_Foundation")]"#);
+        assert_eq!(Gen { root: "Microsoft", relative: "Microsoft.UI.Composition.Diagnostics", ignore_windows_features: false, docs: true, build: false }.gen_cfg_doc(&features).as_str(), r#"#[doc = "*Required features: `UI_Composition_Diagnostics`, `Windows_Foundation`*"]"#);
 
         let mut features = BTreeSet::new();
         features.insert("Microsoft.Foundation");
-        assert_eq!(Gen { root: "Microsoft", relative: "", ignore_windows_features: false, docs: false }.gen_cfg(&features).as_str(), r#"#[cfg(feature = "Foundation")]"#);
-        assert_eq!(
-            Gen {
-                root: "Microsoft",
-                relative: "Microsoft.UI.Composition.Diagnostics",
-                ignore_windows_features: false,
-                docs: true
-            }
-            .gen_cfg_doc(&features)
-            .as_str(),
-            r#"#[doc = "*Required features: `UI_Composition_Diagnostics`, `Foundation`*"]"#
-        );
+        assert_eq!(Gen { root: "Microsoft", relative: "", ignore_windows_features: false, docs: false, build: false }.gen_cfg(&features).as_str(), r#"#[cfg(feature = "Foundation")]"#);
+        assert_eq!(Gen { root: "Microsoft", relative: "Microsoft.UI.Composition.Diagnostics", ignore_windows_features: false, docs: true, build: false }.gen_cfg_doc(&features).as_str(), r#"#[doc = "*Required features: `UI_Composition_Diagnostics`, `Foundation`*"]"#);
     }
 }
