@@ -28,20 +28,19 @@ impl InterfaceInfo {
 
     pub fn gen_methods(interfaces: &[Self], gen: &Gen) -> TokenStream {
         let mut method_names = BTreeMap::<String, u32>::new();
-        let mut tokens = TokenStream::with_capacity();
+        let mut tokens = TokenStream::new();
 
         for interface in interfaces {
+            if interface.is_base && gen.relative.starts_with("Windows.UI.Xaml") && !interface.def.namespace().starts_with("Windows.Foundation") {
+                continue;
+            }
+
             for (vtable_offset, method) in interface.def.methods().enumerate() {
                 let name = method.rust_name();
                 let overload = method_names.entry(name.clone()).or_insert(0);
                 *overload += 1;
 
-                let info = MethodInfo {
-                    name,
-                    vtable_offset: vtable_offset as u32 + 6,
-                    overload: *overload,
-                    is_deprecated: method.is_deprecated(),
-                };
+                let info = MethodInfo { name, vtable_offset: vtable_offset as u32 + 6, overload: *overload, is_deprecated: method.is_deprecated() };
 
                 let signature = method.signature(&interface.def.generics);
                 tokens.combine(&gen_winrt_method(&signature, &info, interface, gen));
