@@ -1,7 +1,7 @@
 use super::*;
 
 pub fn gen_sys_file(root: &'static str, tree: &TypeTree, ignore_windows_features: bool) -> TokenStream {
-    let gen = Gen { relative: tree.namespace, root, ignore_windows_features, docs: false };
+    let gen = Gen { relative: tree.namespace, root, ignore_windows_features, docs: false, build: false };
     let types = gen_sys(tree, &gen);
 
     let namespaces = tree.namespaces.iter().filter_map(move |(name, tree)| {
@@ -24,7 +24,7 @@ pub fn gen_sys_file(root: &'static str, tree: &TypeTree, ignore_windows_features
 }
 
 pub fn gen_source_file(root: &'static str, tree: &TypeTree, ignore_windows_features: bool) -> TokenStream {
-    let gen = Gen { relative: tree.namespace, root, ignore_windows_features, docs: false };
+    let gen = Gen { relative: tree.namespace, root, ignore_windows_features, docs: false, build: false };
 
     let types = tree.types.values().map(move |t| gen_type_entry(t, &gen));
 
@@ -50,7 +50,7 @@ pub fn gen_source_file(root: &'static str, tree: &TypeTree, ignore_windows_featu
 pub fn gen_source_tree() -> TokenStream {
     let reader = TypeReader::get();
 
-    namespace_iter(&reader.types).fold(TokenStream::with_capacity(), |mut accum, n| {
+    namespace_iter(&reader.types).fold(TokenStream::new(), |mut accum, n| {
         accum.combine(&n);
         accum
     })
@@ -89,7 +89,7 @@ fn gen_namespaces<'a>(namespaces: &'a BTreeMap<&'static str, TypeTree>) -> impl
     })
 }
 
-fn gen_type_entry(entry: &TypeEntry, gen: &Gen) -> TokenStream {
+pub fn gen_type_entry(entry: &TypeEntry, gen: &Gen) -> TokenStream {
     if entry.include == TypeInclude::None {
         return TokenStream::new();
     }
